@@ -32,8 +32,8 @@ async def _allocate(session: ClientSession,
 
 
 async def _upload(session: ClientSession,
-                   path,
-                   url):
+                  path,
+                  url):
     async with aiofiles.open(path, "rb") as f:
         size = await aiofiles.os.path.getsize(path)
         headers = {"content-length": str(size)}
@@ -45,13 +45,13 @@ async def _upload(session: ClientSession,
 class OaasInvocationCtx:
     success: bool = True
     error: str = None
-    extensions: dict[str,str] = None
+    extensions: dict[str, str] = None
+    allocate_url_dict = None
+    allocate_main_url_dict = None
 
     def __init__(self, json_dict: Dict):
         self.json_dict = json_dict
         self.task = OaasTask(json_dict)
-        self.allocate_url_dict = None
-        self.allocate_main_url_dict = None
 
     @property
     def args(self):
@@ -214,12 +214,11 @@ class Router:
     def register(self, fn_key: str, handler: Handler):
         self._handlers[fn_key] = handler
 
-    def handle_task(self, json_task):
+    async def handle_task(self, json_task):
         ctx = OaasInvocationCtx(json_task)
         if ctx.task.func in self._handlers:
-            self._handlers[ctx.task.func].handle(ctx)
+            await self._handlers[ctx.task.func].handle(ctx)
             resp = ctx.create_completion()
             return resp
         else:
             return None
-
